@@ -1,6 +1,6 @@
 """TaskTimer for ScriptEngine."""
 
-from scriptengine.tasks.base import Task
+from scriptengine.tasks.core import Task
 from scriptengine.exceptions import ScriptEngineTaskRunError
 
 
@@ -18,8 +18,6 @@ class TaskTimer(Task):
                             'instances': As for 'classes', plus times are
                                          accumulated for each individual task
                                          instance.
-        set (optional):     The context key used to store timing information.
-                            This argument is needed if 'mode' is not False.
         logging (optional): one of
                             False:   No time logging after each task. Does not
                                      affect statistic collection.
@@ -35,7 +33,6 @@ class TaskTimer(Task):
     def run(self, context):
 
         mode = self.getarg('mode', context)
-        self.log_info(f'Setting timer mode to "{mode}"')
         if mode not in (False, 'basic', 'classes', 'instances'):
             msg = ('Unknown mode in TaskTimer: must be one of "off", "basic", '
                    f'"classes", "instances", not "{mode}"')
@@ -43,21 +40,17 @@ class TaskTimer(Task):
             raise ScriptEngineTaskRunError(msg)
 
         if mode:
-            timer_key = self.getarg('set', context)
-            timer_context = context.setdefault(timer_key, {})
-            self.log_debug(f'Using timer key "{timer_key}"')
-
-            timer_context['mode'] = mode
-
             logging = self.getarg('logging', context, default=False)
             if logging not in (False, 'info', 'debug'):
                 msg = ('Unknown logging mode in TaskTimer: must be one of '
                        f'"off", "info", "debug", not "{logging}"')
                 self.log_error(msg)
                 raise ScriptEngineTaskRunError(msg)
-            timer_context['logging'] = logging
-
-            context['_se_task_timing'] = timer_key
-
+            self.log_info(f'Task timing activated in mode "{mode}" and '
+                          f'logging to "{logging}"')
         else:
-            context['_se_task_timing'] = False
+            logging = False
+            self.log_info('Task timing is switched off')
+
+        context['se']['tasks']['timing']['mode'] = mode
+        context['se']['tasks']['timing']['logging'] = logging
